@@ -417,7 +417,7 @@ class ChemStationConfig:
     @property
     def method_path(self) -> pathlib.Path:
         """path to the method save directory"""
-        return self._core
+        return self._method
 
     @method_path.setter
     def method_path(self, value: Union[str, pathlib.Path]):
@@ -429,7 +429,7 @@ class ChemStationConfig:
     @property
     def sequence_path(self) -> pathlib.Path:
         """path to the sequence save directory"""
-        return self._core
+        return self._sequence
 
     @sequence_path.setter
     def sequence_path(self, value: Union[str, pathlib.Path]):
@@ -448,6 +448,23 @@ class ChemStationConfig:
             ChemStation ini files.
         :return: instances created via the ini
         """
+        def get_from_ini(section, *keys, default=None):
+            """
+            Attempts to retrieve the keys in order from the provided section. If no keys exist, the default value is
+            returned.
+
+            :param section: section name
+            :param keys: keys to attempt to retrieve from the section in order
+            :param default: default value to return if not found
+            """
+            for key in keys:
+                try:
+                    return configuration.get(section, key)
+                except configparser.NoOptionError:
+                    continue
+            logger.error(f'no provided keys were defined in the section {section} ({keys})')
+            return default
+
         if ini_path is None:
             ini_path = cls.DEFAULT_INI_LOCATION
         ini_path = pathlib.Path(ini_path)
@@ -466,10 +483,10 @@ class ChemStationConfig:
             try:
                 pcsnum = f'PCS,{inst}'
                 out.append(cls(
-                    core_path=configuration.get(pcsnum, '_EXEPATH$'),
-                    method_path=configuration.get(pcsnum, '_METHPATH$'),
-                    sequence_path=configuration.get(pcsnum, '_SEQPATH$'),
-                    data_path=configuration.get(pcsnum, '_DATAPATH$'),
+                    core_path=get_from_ini(pcsnum, '_EXEPATH$'),
+                    method_path=get_from_ini(pcsnum, '_METHPATH$', '_CONFIGMETPATH$'),
+                    sequence_path=get_from_ini(pcsnum, '_SEQPATH$', '_CONFIGSEQPATH$'),
+                    data_path=get_from_ini(pcsnum, '_DATAPATH$'),
                     version=version,
                     number=inst,
                 ))
